==> karchiver-3.1.1.tar.bz2: karchiver-3.1.1/karchiver/cgpg.cpp <==
/***************************************************************************
                          cgpg.cpp  -  description
                             -------------------
    begin                : Sat Dec 1 2001
    copyright            : (C) 2001 by Eric Coquelle
    email                : coquelle@caramail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <klocale.h>
#include <kinputdialog.h>
#include <kprocess.h>

#include "cgpg.h"

CGPG::CGPG(QWidget *parent, const char *name ) : QWidget(parent,name) {
}
CGPG::~CGPG(){
}

/** Set the archivename to crypt to name */
void CGPG::setArchiveToProcess( QString name ){
	archivename=name;
}

/** Crypt an archive */
void CGPG::cryptArchive(){
	QString receiver;
	KProcess process;
	bool validate;
	
	 receiver = KInputDialog::getText (i18n("Karchiver - crypto module"), i18n("Please enter below the email adress of the receiver, as it appears in yours GPG public keys (type gpg --list-keys [user] in a shell to check)"), i18n("someone@example.com"), &validate);
	 if(validate==false)
	 	return;

  process.clearArguments();
  process << "gpg" << "-r" << receiver << "-e" << archivename;
  process.start(KProcess::Block);
}

/** decrypt current archive */
void CGPG::decryptArchive(){
			KProcess proc;
			proc.clearArguments();
			proc << "konsole";
			proc << "-e";
			proc << "gpg";
			proc << "'";
			proc  << archivename;
			proc << "'";
			proc.start(KProcess::Block);
}

#include "cgpg.moc"

==> karchiver-3.4.2.b4.tar.bz2: karchiver-3.4.2.b4/karchiver/cgpg.cpp <==
/***************************************************************************
                          cgpg.cpp  -  description
                             -------------------
    begin                : Sat Dec 1 2001
    copyright            : (C) 2001 by Eric Coquelle
    email                : coquelle@caramail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <klocale.h>
#include <kinputdialog.h>
#include <kprocess.h>

#include "cgpg.h"

CGPG::CGPG(QWidget *parent, const char *name ) : QWidget(parent,name) {
}
CGPG::~CGPG(){
}

/** Set the archivename to crypt to name */
void CGPG::setArchiveToProcess( QString name ){
	archivename=name;
}

/** Crypt an archive */
void CGPG::cryptArchive(){
	QString receiver;
	KProcess process;
	bool validate;
	
	 receiver = KInputDialog::getText ("Karchiver", i18n("Enter the email address of the receiver"), i18n("someone@example.com"), &validate, NULL);
	 if(validate==false)
	 	return;
	 	
  process.clearArguments();
  process << "gpg" << "-r" << receiver << "-e" << archivename;
  process.start(KProcess::Block);
}

/** decrypt current archive */
void CGPG::decryptArchive(){
			KProcess proc;
			proc.clearArguments();
			proc << "konsole";
			proc << "-e";
			proc << "gpg";
			proc << "'";
			proc  << archivename;
			proc << "'";
			proc.start(KProcess::Block);
}

#include "cgpg.moc"
